# Fibonacci index

## Como usar

### Install

```
    pip install fibonacci_index
```

### Use

```
    from fibonacci_index import fibonacci_index

    index = fibonacci_index.sum(<number>)
```

### Example
```
    from fibonacci_index import fibonacci_index

    index = fibonacci_index.sum(5)

    print(index)
    # 13
```